@@ -2,11 +2,11 @@ package Glib::Object::Introspection::Install::Files;
 
 $self = {
           'typemaps' => [],
+          'inc' => '-I/usr/local/include/gobject-introspection-1.0 -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include -pthread -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include',
           'deps' => [
                       'Glib'
                     ],
-          'libs' => '-L/usr/local/lib -lgirepository-1.0 -lgobject-2.0 -lintl -lglib-2.0 -Wl,--export-dynamic -pthread -L/usr/local/lib -lgmodule-2.0 -lintl -lglib-2.0 -L/usr/local/lib -lffi',
-          'inc' => '-I/usr/local/include/gobject-introspection-1.0 -I/usr/local/include -pthread -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include -pthread -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include'
+          'libs' => '-L/usr/local/lib -lgirepository-1.0 -lgobject-2.0 -lglib-2.0 -lintl -Wl,--export-dynamic -L/usr/local/lib -pthread -lgmodule-2.0 -lglib-2.0 -lintl -L/usr/local/lib -lffi'
         };
 
 
